const getMakers = () => {
  const makers = [
    {
      name: '@electron-forge/maker-zip',
      platforms: [
        'darwin',
        'win32',
      ],
    },
  ]

  if (process.env.MAKE_PKG) {
    if (process.platform === 'darwin') {
      makers.push({
        name: '@electron-forge/maker-pkg',
      })
    } else {
      console.log('PKG builds available only on MacOS, skipping...')
    }
  }

  if (process.env.MAKE_DMG) {
    if (process.platform === 'darwin') {
      makers.push({
        name: '@electron-forge/maker-dmg',
      })
    } else {
      console.log('DMG builds available only on MacOS, skipping...')
    }
  }

  if (process.env.MAKE_SQUIRREL) {
    if (process.platform === 'win32') {
      makers.push({
        name: '@electron-forge/maker-squirrel',
        config: {
          certificateFile: process.env.MAKER_SQUIRREL_CERT_FILE,
          certificatePassword: process.env.MAKER_SQUIRREL_CERT_PASSWORD,
        }
      })
    } else {
      console.log('Squirrel.Windows builds available only on Win32, skipping...')
    }
  }

  if (process.env.MAKE_APPX) {
    if (process.platform === 'win32') {
      makers.push({
        name: '@electron-forge/maker-appx',
        config: {
          publisher: process.env.MAKER_APPX_PUBLISHER,
          devCert: process.env.MAKER_APPX_CERT_FILE,
          certPass: process.env.MAKER_APPX_CERT_PASSWORD,
        }
      })
    } else {
      console.log('APPX builds available only on Win32, skipping...')
    }
  }

  return makers
}

const getPublishers = () => {
  const publishers = []

  if (process.env.PUBLISH_NUCLEUS) {
    publishers.push({
      name: '@electron-forge/publisher-nucleus',
      config: {
        host: process.env.PUBLISHER_NUCLEUS_HOST,
        appId: 1,
        channelId: process.env.PUBLISHER_NUCLEUS_CHANNEL || 'main',
        token: process.env.PUBLISHER_NUCLEUS_TOKEN
      }
    })
  }

  return publishers
}

module.exports = {
  packagerConfig: {
    extendInfo: {
      LSUIElement: 1,
    },
    protocols: [
      {
        name: 'Klink',
        schemes: ['klink'],
      },
    ],
    ignore: [
      /node_modules\/\.cache/,
    ]
  },
  plugins: [
    [
      '@electron-forge/plugin-electronegativity',
      {
        isSarif: true,
        parserPlugins: [],
      },
    ],
  ],
  makers: getMakers(),
  publishers: getPublishers(),
}
