import React, { useEffect, useState } from 'react'
import { KlinkDetails } from '../../../common/types'
import { KlinkDetailsWithContacts } from '../../types'
import { getKlinkDetails } from '../../utils'
import KlinkDetailsForm from '../KlinkDetailsForm'
import { getContactsWithPhones, saveContacts } from '../ContactsRepository'
import ActionButtons from '../ActionButtons'

export type KlinkEditorProps = {
  title: string,
  data: string,
  sharedWith: string[],
  notifications: boolean,
  editKlink: (klinkRequest: KlinkDetails) => Promise<void>,
  close(): void
}

const KlinkEditor = ({
  title,
  data,
  sharedWith,
  notifications,
  editKlink,
  close
}: KlinkEditorProps) => {
  const [details, setDetails] = useState<KlinkDetailsWithContacts>({
    title,
    body: data,
    sharedWith: [],
    notifications,
  })

  useEffect(() => {
    getContactsWithPhones(sharedWith).then((contacts) => setDetails((previousDetails) => ({ ...previousDetails, sharedWith: contacts })))
  }, [sharedWith])

  const [loading, setLoading] = useState(false)
  const [error, setError] = useState<string | null>(null)

  const edit = async () => {
    try {
      setLoading(true)
      await saveContacts(details.sharedWith)
      await editKlink(getKlinkDetails(details))
    } catch (e) {
      setError(e)
    } finally {
      setLoading(false)
    }
  }

  return (
    <div>
      {error && (
        <div>
          Error: {error}
        </div>
      )}
      <KlinkDetailsForm
        title={details.title}
        body={details.body}
        sharedWith={details.sharedWith}
        notifications={details.notifications}
        onChange={(details) => {
          setDetails(details)
          setError(null)
        }}
      />
      <ActionButtons actionName="Edit" loading={loading} action={edit} close={close} />
    </div>
  )
}

export default KlinkEditor
